
#delimit;


/*Set=Up*/
use "data/FDI_by_counterparts.dta", clear;
rename origin country;
replace country="Korea" if country=="South Korea";
replace country="Netherlands" if country=="Netherland";

merge m:1 country using "data/oecd_enforcement2.dta";
drop _merge;
drop if year>2015;
merge m:1 year using "data/cpi.dta";
drop _merge;
fillin country year;
replace oecd_enforce=0 if oecd_enforce==.;
replace oecd_enforce=2 if country=="Finland";
replace oecd_enforce=1 if country=="Brazil";
replace oecd_enforce=1 if country=="Bulgaria";
replace oecd_enforce=1 if country=="Costa Rica";
replace oecd_enforce=1 if country=="Estonia";
replace oecd_enforce=1 if country=="Hungary";
replace oecd_enforce=1 if country=="Iceland";
replace oecd_enforce=1 if country=="Israel";
replace oecd_enforce=1 if country=="Poland";
replace oecd_enforce=1 if country=="New Zealand";
replace oecd_enforce=1 if country=="South Africa";


encode country, generate(country_id);
xtset country_id year;

generate oecd=1 if oecd_enforce>=1;
replace oecd=0 if oecd_enforce==0;

label variable oecd "OECD-ACB";
label values oecd oecd;
label define oecd 0 "Non-Signatory" 1 "Signatory"; 

generate phase3=1 if year>=2010;
replace phase3=0 if year<2010;

label variable phase3 "Phase 3";
label values phase3 phase3;
label define phase3 0 "Before" 1 "After" ;

replace new_projects=0 if new_projects==.;
replace new_fdi_inflows=0 if new_fdi_inflows==.;



#delimit;
generate tax_haven=1 if country=="Anguilla"|country=="Bahamas"|country=="Bahrain"|country=="Barbados"|country=="Belize"|country=="Bermuda"|country=="British Virgin Islands"|country=="British West Indies"|
						country=="Cayman Islands"|country=="Channel Islands"|country=="Cook Islands"|country=="Costa Rica"|country=="Dominica"|country=="Hong Kong"|country=="Ireland"|country=="Island of Nevis"|                    
						country=="Isle of Man"|country=="Jordan"|country=="Lebanon"|country=="Liechtenstein"|country=="Luxembourg"|country=="Macau"|country=="Maldives"|country=="Malta"||country=="Marshall Islands"|
						country=="Mauritius"|country=="Saint Kitts and Nevis"|country=="Saint Vincent and the Grenadines"|country=="Samoa"|country=="Seychelles"|country=="Panama"|country=="Singapore"|country=="Switzerland"|
						country=="Taiwan";
replace tax_haven=0 if tax_haven==.;

label variable tax_haven "Tax Haven";
label values tax_haven tax_haven;
label define tax_haven 0 "Non-Haven" 1 "Haven" ;


#delimit;
by year, sort: egen total_projects=sum(new_projects);
by year, sort: egen total_capital=sum(new_fdi_inflows);


gen share_projects=new_projects/total_projects;
gen share_investment=new_fdi_inflows/total_capital;
generate invest_cpi= new_fdi_inflows/cpi1001994;
replace invest_cpi=0 if invest_cpi==.;
generate ln_capital=ln(invest_cpi+1);
save "data/oecd_country_level.dta", replace;

/************************************************************************************************************************/
/*Table 2 & SI5 Table4*/


/*Country Level Analysis*/
/*Table 2, Model 5 & Model 6*/
#delimit;
areg share_projects i.oecd_enforce##i.phase3 i.year, robust absorb(country_id);
outreg2 using "tables/Table2", bdec(3) tdec(3) e(rmse) ctitle("Proj. Share") noaster keep(1.oecd_enforce 2.oecd_enforce 1.phase3 1.oecd_enforce#1.phase3 2.oecd_enforce#1.phase3 ) addtext("Country FE", Yes, "Year FE", Yes) replace;
areg share_investment i.oecd_enforce##i.phase3 i.year, robust absorb(country_id);
outreg2 using "tables/Table2", bdec(3) tdec(3) e(rmse) ctitle("Inv. Share") noaster keep(1.oecd_enforce 2.oecd_enforce 1.phase3 1.oecd_enforce#1.phase3 2.oecd_enforce#1.phase3 ) addtext("Country FE", Yes, "Year FE", Yes);

/*SI5 Table 4, Model 5 & Model 6*/
#delimit;
areg new_projects i.oecd_enforce##i.phase3 i.year, robust absorb(country_id);
outreg2 using "tables/SI_Table4", bdec(3) tdec(3) e(rmse) ctitle("New Proj.") noaster keep(1.oecd_enforce 2.oecd_enforce 1.phase3 1.oecd_enforce#1.phase3 2.oecd_enforce#1.phase3 ) addtext("Country FE", Yes, "Year FE", Yes) replace;
areg ln_capital i.oecd_enforce##i.phase3 i.year, robust absorb(country_id);
outreg2 using "tables/SI_Table4", bdec(3) tdec(3) e(rmse) ctitle("Inv. Size (ln)") noaster keep(1.oecd_enforce 2.oecd_enforce 1.phase3 1.oecd_enforce#1.phase3 2.oecd_enforce#1.phase3 ) addtext("Country FE", Yes, "Year FE", Yes);

/*Dropping China and Taiwan*/
/*Table 2, Model 7 & 8*/
drop if country_id==19|country_id==79;
areg share_projects i.oecd_enforce##i.phase3 i.year, robust absorb(country_id);
outreg2 using "tables/Table2", bdec(3) tdec(3) e(rmse) ctitle("Proj. Share") noaster keep(1.oecd_enforce 2.oecd_enforce 1.phase3 1.oecd_enforce#1.phase3 2.oecd_enforce#1.phase3 ) addtext("Country FE", Yes, "Year FE", Yes);
areg share_investment i.oecd_enforce##i.phase3 i.year, robust absorb(country_id);
outreg2 using "tables/Table2", bdec(3) tdec(3) e(rmse) ctitle("Inv. Share") noaster keep(1.oecd_enforce 2.oecd_enforce 1.phase3 1.oecd_enforce#1.phase3 2.oecd_enforce#1.phase3 ) addtext("Country FE", Yes, "Year FE", Yes);

/*SI5 Table 4, Model 7 & 8*/
areg new_projects i.oecd_enforce##i.phase3 i.year, robust absorb(country_id);
outreg2 using "tables/SI_Table4", bdec(3) tdec(3) e(rmse) ctitle("New Proj.") noaster keep(1.oecd_enforce 2.oecd_enforce 1.phase3 1.oecd_enforce#1.phase3 2.oecd_enforce#1.phase3 ) addtext("Country FE", Yes, "Year FE", Yes);
areg ln_capital i.oecd_enforce##i.phase3 i.year, robust absorb(country_id);
outreg2 using "tables/SI_Table4", bdec(3) tdec(3) e(rmse) ctitle("Inv. Size (ln)") noaster keep(1.oecd_enforce 2.oecd_enforce 1.phase3 1.oecd_enforce#1.phase3 2.oecd_enforce#1.phase3 ) addtext("Country FE", Yes, "Year FE", Yes);

/*Enforcement Level Analysis*/
#delimit;
use "data/oecd_country_level.dta", clear;
collapse (sum) share_projects share_investment (mean) new_projects invest_cpi phase3, by(oecd_enforce year);
generate ln_capital=ln(invest_cpi+1);

/*SI Table 3*/
#delimit;
sum share_project share_investment new_projects ln_capital oecd_enforce phase3;
pwcorr share_project share_investment new_projects ln_capital oecd_enforce phase3, star(5);

/*Table 2, Models 1 & 2*/
#delimit;
reg share_projects i.oecd_enforce##i.phase3, robust;
outreg2 using "tables/Table2", bdec(3) tdec(3) e(rmse) ctitle("Proj. Share") noaster keep(1.oecd_enforce 2.oecd_enforce 1.phase3 1.oecd_enforce#1.phase3 2.oecd_enforce#1.phase3 ) addtext("Country FE", No, "Year FE", No);
reg share_investment i.oecd_enforce##i.phase3 i.year, robust;
outreg2 using "tables/Table2", bdec(3) tdec(3) e(rmse) ctitle("Inv. Share") noaster keep(1.oecd_enforce 2.oecd_enforce 1.phase3 1.oecd_enforce#1.phase3 2.oecd_enforce#1.phase3 ) addtext("Country FE", No, "Year FE", No);

/*SI5 Table 4, Models 1 & 2*/
#delimit;
reg new_projects i.oecd_enforce##i.phase3, robust;
outreg2 using "tables/SI_Table4", bdec(3) tdec(3) e(rmse) ctitle("New Proj.") noaster keep(1.oecd_enforce 2.oecd_enforce 1.phase3 1.oecd_enforce#1.phase3 2.oecd_enforce#1.phase3 ) addtext("Country FE", No, "Year FE", No);
reg ln_capital i.oecd_enforce##i.phase3 i.year, robust;
outreg2 using "tables/SI_Table4", bdec(3) tdec(3) e(rmse) ctitle("Inv. Size (ln)") noaster keep(1.oecd_enforce 2.oecd_enforce 1.phase3 1.oecd_enforce#1.phase3 2.oecd_enforce#1.phase3 ) addtext("Country FE", No, "Year FE", No);


#delimit;
use "data/oecd_country_level.dta", clear;
drop if country_id==19|country_id==79;
collapse (sum) share_projects share_investment (mean) new_projects invest_cpi phase3, by(oecd_enforce year);
generate ln_capital=ln(invest_cpi+1);

/*Table 2, Models 3 & 4*/
#delimit;
reg share_projects i.oecd_enforce##i.phase3, robust;
outreg2 using "tables/Table2", bdec(3) tdec(3) e(rmse) ctitle("Proj. Share") noaster keep(1.oecd_enforce 2.oecd_enforce 1.phase3 1.oecd_enforce#1.phase3 2.oecd_enforce#1.phase3 ) addtext("Country FE", No, "Year FE", No);
reg share_investment i.oecd_enforce##i.phase3 i.year, robust;
outreg2 using "tables/Table2", bdec(3) tdec(3) e(rmse) ctitle("Inv. Share") noaster keep(1.oecd_enforce 2.oecd_enforce 1.phase3 1.oecd_enforce#1.phase3 2.oecd_enforce#1.phase3 ) addtext("Country FE", No, "Year FE", No) excel;

/*SI Table 4, Models 3 & 4*/
#delimit;
reg new_projects i.oecd_enforce##i.phase3, robust;
outreg2 using "tables/SI_Table4", bdec(3) tdec(3) e(rmse) ctitle("New Proj.") noaster keep(1.oecd_enforce 2.oecd_enforce 1.phase3 1.oecd_enforce#1.phase3 2.oecd_enforce#1.phase3 ) addtext("Country FE", No, "Year FE", No);
reg ln_capital i.oecd_enforce##i.phase3 i.year, robust;
outreg2 using "tables/SI_Table4", bdec(3) tdec(3) e(rmse) ctitle("Inv. Size (ln)") noaster keep(1.oecd_enforce 2.oecd_enforce 1.phase3 1.oecd_enforce#1.phase3 2.oecd_enforce#1.phase3 ) addtext("Country FE", No, "Year FE", No) excel;

/************************************************************************************************************************/
#delimit;
use "data/oecd_country_level.dta", clear;
collapse (sum) share_projects share_investment (mean) new_projects invest_cpi phase3, by(oecd_enforce year);
generate ln_capital=ln(invest_cpi+1);

/************************************************************************************************************************/
/*Figure 4*/

#delimit;
twoway (line share_projects year if oecd_enforce==0, lcolor(gs4)) (line share_projects year if oecd_enforce==1, lcolor(gs12) lpattern(dash)) (line share_projects year if oecd_enforce==2, lcolor(gs8) lpattern(short_dash)), xline(2009, lpattern(dash) lcolor(purple) lwidth(medthick))
		legend(rows(1) label(1 "Non-Signatory") label(2 "Non-Enforcer") label(3 "Enforcer")) xlab(2005(1)2015, labsize(vsmall)) xtitle("") ytitle("Share of New FDI Projects in Vietnam", size(medium) margin(medium))
		scheme(s1color);
graph save "graphs/Figure4.gph", replace;
graph export "graphs/Figure4.pdf", as(pdf) replace;

/************************************************************************************************************************/
/*Figure 5*/

#delimit;
twoway (line share_investment year if oecd_enforce==0, lcolor(gs4)) (line share_investment year if oecd_enforce==1, lcolor(gs12) lpattern(dash)) (line share_investment year if oecd_enforce==2, lcolor(gs8) lpattern(short_dash)), xline(2009, lpattern(dash) lcolor(purple) lwidth(medthick))
		legend(rows(1) label(1 "Non-Signatory") label(2 "Non-Enforcer") label(3 "Enforcer")) xlab(2005(1)2015, labsize(vsmall)) xtitle("") ytitle("Share of New FDI Capital in Vietnam", size(medium) margin(medium))
		scheme(s1color);
graph save "graphs/Figure5.gph", replace;
graph export "graphs/Figure5.pdf", as(pdf) replace;

/************************************************************************************************************************/
/*SI3 Figure 1*/
		
#delimit;
twoway (line new_projects year if oecd_enforce==0, lcolor(gs4)) (line new_projects year if oecd_enforce==1, lcolor(gs12) lpattern(dash)) (line new_projects year if oecd_enforce==2, lcolor(gs8) lpattern(short_dash)), xline(2009, lpattern(dash) lcolor(purple) lwidth(medthick))
		legend(rows(1) label(1 "Non-Signatory") label(2 "Non-Enforcer") label(3 "Enforcer")) xlab(2005(1)2015, labsize(vsmall)) xtitle("") ytitle("New Projects in Vietnam (#)", size(medium) margin(medium))
		scheme(s1color);
graph save "graphs/SI_Figure1.gph", replace;
graph export "graphs/SI_Figure1.pdf", as(pdf) replace;

/************************************************************************************************************************/
/*SI4 Figure 2*/
		
		#delimit;
twoway (line ln_capital year if oecd_enforce==0, lcolor(gs4)) (line ln_capital year if oecd_enforce==1, lcolor(gs12) lpattern(dash)) (line ln_capital year if oecd_enforce==2, lcolor(gs8) lpattern(short_dash)), xline(2009, lpattern(dash) lcolor(purple) lwidth(medthick))
		legend(rows(1) label(1 "Non-Signatory") label(2 "Non-Enforcer") label(3 "Enforcer")) xlab(2005(1)2015, labsize(vsmall)) xtitle("") ytitle("FDI Capital in Vietnam (Millions USD, ln)", size(medium) margin(medium))
		scheme(s1color);
graph save "graphs/SI_Figure2.gph", replace;
graph export "graphs/SI_Figure2.pdf", as(pdf) replace;		



/************************************************************************************************************************/
/*Exporting Country Level Data*/
#delimit;
use "data/oecd_country_level.dta", clear;
keep country year share_projects share_investment;
reshape wide share_projects share_investment, i(country) j(year);
save "data/country_wide.dta", replace;






