
/*Generate Management Dataset for Foregn Firms*/
#delimit;
set more off;

use  "data/Raw_PCI2017.dta", clear;
generate year=2017;
generate FDI=1;


/*******************************************************************************************************************************/

/*Sectors*/
#delimit;
split ma_nganhkd, generate(digit) parse(A B C D E F G H I J K L M N O P Q R S T U V W X Y Z) limit(2);
drop digit1;
split ma_nganhkd, generate(sector) parse(0 1 2 3 4 5 6 7 8 9) limit(1);
encode sector1, gen(sector_id1);
order digit2;
generate isic_dig1=regexs(1) if regexm(digit2, "([0-9])([0-9])([0-9])([0-9])");
generate isic_dig2=regexs(2) if regexm(digit2, "([0-9])([0-9])([0-9])([0-9])");
generate isic_dig3=regexs(3) if regexm(digit2, "([0-9])([0-9])([0-9])([0-9])");
generate isic_dig4=regexs(4) if regexm(digit2, "([0-9])([0-9])([0-9])([0-9])");
egen isic_rev4_2digitcode = concat(isic_dig1 isic_dig2);
lab var isic_rev4_2digitcode "ISIC Revision 4 2 Digit Code";
egen isic_rev4_4digit = concat(isic_dig1 isic_dig2 isic_dig3 isic_dig4);
lab var isic_rev4_4digit "ISIC Revision 4 4 Digit Code";
sort isic_rev4_4digit;
egen sect_plus = concat(sector1 isic_dig1 isic_dig2) if sector1=="C";
replace sect_plus=sector1 if sector1 !="C";
rename sect_plus sector_plus;
lab var sector_plus "Broad Sector and 2-Digit Manufacturing";

/*Consolidate Manufacturing Sectors with Low Representation*/
#delimit;
tab sector_plus if sector1=="C";
replace sector_plus="C32" if a6_1==1 &  isic_dig1=="";
replace sector_plus="F" if a6_2==1 &  isic_dig1=="";
replace sector_plus="G" if a6_3==1 &  isic_dig1=="";
replace sector_plus="A" if a6_4==1 &  isic_dig1=="";
replace sector_plus="B" if a6_5==1 &  isic_dig1=="";
replace sector_plus="K" if a6_5==1 &  isic_dig1=="";




/***********************************************Create Size Variables***************************************************/


#delimit;
generate labor_origin=a10_1;
lab var labor_origin "Number of Employees in Firm at Establishment";

generate labor_today=a10_3;
lab var labor_today "Number of Employees in Firm at Establishment";

generate capital_origin=a5_1;
lab var capital_origin "Investment Size of Firm in USD $100,000";

generate capital_today=a5_3;
lab var capital_today "Investment Size of Firm in USD $100,000";

gen age=2017-a1;

#delimit;
generate capital=0.25 if a5_1==1 ;
replace capital=0.75 if a5_1==2 ;
replace capital=3 if a5_1==3 ;
replace capital=7.5 if a5_1==4 ;
replace capital=30 if a5_1==5 ;
replace capital= 125 if a5_1==6 ;
replace capital=350 if a5_1==7 ;
replace capital=500 if a5_1==8 ;


/*Employment size to date*/
#delimit;
generate labor=2.5 if a10_1==1 ;
replace labor=5 if a10_1==2 ;
replace labor=25 if a10_1==3 ;
replace labor=125 if a10_1==4 ;
replace labor=250 if a10_1==5 ;
replace labor=400 if a10_1==6 ;
replace labor=750 if a10_1==7 ;
replace labor=1500 if a10_1==8 ;




/******************************************************************************************************/


/*******************************Transparency and Corruption*********************************************/

/*Good Managers Pay More Bribes*/

/*Bribes at Registration*/
#delimit;
generate reg_bribe=c4_2017;
lab var reg_bribe  "Bribe at Registration";

/*Bribes for Land*/
generate land_bribe=1 if d6_2_5==1|d6_2_5==2;
replace land_bribe=0 if d6_2_5==0;
lab var land_bribe "Bribe for Land Fees";

/*Bribes at Inspection*/
generate inspection_bribe=1 if e2_2016==1;
replace inspection_bribe=0 if e2_2016==0;
lab var inspection_bribe "Bribe for Land Fees";
rename  e2_1_1 inspection_offered;
lab var inspection_offered "I offered Bribe";
rename e2_1_2 inspection_asked;
lab var inspection_asked"Inspector Asked";
rename e2_1_3 inspection_normal;
lab var inspection_normal "Bribe Traditional";

/*Management Time*/
rename e3 time_spent;

/*Regulations Used to Extract Rents*/
generate regulation_rents=5-e5;
lab var regulation_rents "Regulations Used to Extract Rents (Agree)";
label values regulation_rents agree;
label define agree 1 "Strongly Disagree" 2 "Disagree"  3 "Agree" 4 "Strongly Agree";


/*Share of Bribes*/
#delimit;
generate bribe_cost=0 if e6==1;
replace bribe_cost=.5 if e6==2;
replace bribe_cost=1.5 if e6==3;
replace bribe_cost=3.5 if e6==4;
replace bribe_cost=7.5 if e6==5;
replace bribe_cost=12.5 if e6==6;
replace bribe_cost=30 if e6==8;
generate ln_bribe=ln(bribe_cost+.001);
lab var bribe_cost "Share of Bribes/Revenue (%)";

/*Bribe Common*/
#delimit;
gen bribe_common=1 if bribe_cost>0 & bribe_cost !=.;
replace bribe_common=0 if bribe_cost==0;
lab var bribe_common "Bribes are Common in Vietnam=1";

/*Service Delivered*/
generate service_delivered=6-e7;
lab var service_delivered "Service is Delivered";
label values service_delivered always;
label define always 1 "Never" 2 "Seldom"  3 "Sometimes" 4 "Usually" 5 "Always";


/*Procurement*/
rename e8_2017 procurement_bid;
rename e8_2017_1 procurement_learn;
rename e8_2017_1_1 procurement_channel;
generate procurement_bribe= 5-e8_2017_2;
label values procurement_bribe agree;
rename e8_2017_3 procurement_bribe_size;
generate ln_procurement_size=ln(procurement_bribe_size+.001);
rename e8_2017_4_1 procurement_bribe_offer;
rename e8_2017_4_2 procurement_bribe_requested;
rename e8_2017_4_3 procurement_bribe_traditional; 

generate procurement_refuse=6-e9_2017 ;
lab var procurement_refuse "Refusal to Pay is Disadvantaged";
label values procurement_refuse always;
 
rename e10_2017 procurement_win;
rename f7 customs_export;
rename f8 customs_import;
rename f9 customs_bribe;
rename i1 dispute_dich;
rename i2 dispute_court;
replace dispute_court=0 if dispute_court==2;
replace dispute_court=1 if dispute_court==3;
rename i3_4 dispute_bribe;

generate op_costs= g11;
generate China=0 if form=="A";
replace China=1 if form=="B";
lab var op_costs "Share of Operating Costs";
rename j2 no_clarity;

rename a8 legal_form_FDI;
rename a9 mnc;
rename a9_3 mnc_state;
lab var mnc "Multinational Corporation";
label values mnc mnc;
label define mnc 0 "Single Country" 1 "MNC";

generate expand=1 if a13<=2;
replace expand=0 if a13>2;
generate profitable=1 if a11_3>=5 & a11_3<10;
replace profitable=0 if a11_3<=4;
generate ln_sales=ln(a14+1);
generate ln_expenses=ln(a16+1);

/******************************************************************************************************/

/*Management Quality*/

#delimit;
generate man1_production=2 if f9_2017==1;
replace man1_production=3 if f9_2017==2;
replace man1_production=4 if f9_2017==3;
replace man1_production=1 if f9_2017==4;
lab var man1_production "Solution to Production Problem";

generate man2_performance=2 if f10_2017==1;
replace man2_performance=3 if f10_2017==2;
replace man2_performance=4 if f10_2017==3;
replace man2_performance=1 if f10_2017==4;
lab var man2_performance "Use of Performance Indicators";

generate man3_promotion=4 if f11_2017==1;
replace man3_promotion=3 if f11_2017==2;
replace man3_promotion=2 if f11_2017==3;
replace man3_promotion=1 if f11_2017==4;
lab var man3_promotion "Basis for Promotion (Non-Manager)";

#delimit;
generate man4_dismissal=2 if f12_2017==3;
replace man4_dismissal=3 if f12_2017==2;
replace man4_dismissal=4 if f12_2017==1;
pwcorr man4_dismissal f12_2017, star(5);
lab var man4_dismissal "Speed of Dismissal";


generate man5_data=1 if f13_2017==1;
replace man5_data=2 if f13_2017==2;
replace man5_data=2 if f13_2017==3;
replace man5_data=3 if f13_2017==4;
replace man5_data=4 if f13_2017==5;
lab var man5_data "Use of Data in Decision Making";
egen management_quality_index=rowmean(man1 man2 man3 man5);
lab var management_quality_index "Quality of Management (1-4)";
tabstat management_quality, by(pci_id);

/******************************************************************************************************************************/
/*Main Customer*/

/*Customer*/
#delimit;
generate sales_state=1 if a15_a==1| a15_b==1;
replace sales_state=0 if sales_state==.;
lab var sales_state "SOEs/Gov't Agency";

generate sales_domestic=1 if a15_c==1|a15_c2==1;
replace sales_domestic=0 if sales_domestic==.;
lab var sales_domestic "Domestic Firms/Domestic Individuals";

generate sales_foreign=1 if a15_d1==1|a15_d2==1;
replace sales_foreign=0 if sales_foreign==.;
lab var sales_foreign "Foreign Firms/Foreign Individuals";

generate sales_export=1 if a15_e==1|a15_f==1|a15_g==1;
replace sales_export=0 if sales_export==.;
lab var sales_export "Export Directly or Indirectly";


generate country= companycountry;
replace country= managercountry if companycountry==""|companycountry=="Vietnam";
replace country="Netherlands" if country=="Netherland";
replace country="United Kingdom" if country=="British Virgin Islands";
replace country="China" if country=="Hong Kong";
replace country="Korea" if country=="Republic of Korea";
replace country="United States" if country=="United States of America";


merge m:1 country using "data/oecd_enforcement2.dta";


label variable oecd_enforce "Enforcement (Transparency International)";
label values oecd_enforce enforce;
label define enforce 0 "Non-Signatory" 1 "Non-Enforcer" 2 "Enforcer" ;

generate oecd=1 if oecd_enforce>=1;
replace oecd=0 if oecd_enforce==0;
replace oecd_enforce=0 if country=="Russia";
replace oecd_enforce=1 if country=="Slovenia";

label variable oecd "OECD-ACB";
label values oecd oecd;
label define oecd 0 "Non-Signatory" 1 "Signatory" ;

#delimit;
generate profit_margin=((a14-a16)/capital);
generate ln_profitmargin=ln(profit_margin+1) if profit_margin>=0;
replace ln_profitmargin=0-ln(0-(profit_margin+1)) if profit_margin<0;


/******************************************************************************************************************************/



#delimit;
keep country year FDI pci_id id_dn legal_form_FDI mnc mnc_state companycountry managercountry gender position a1 sector* isic* labor_origin labor_today capital_origin capital_today
 age reg_bribe land_bribe inspection* regulation_rents bribe_cost ln_bribe bribe_common procurement* ln_procurement 
time_spent op_costs e7_2017_1_1 e7_2017_1_2 e7_2017_1_3 e7_2017_1_4 b2 b6* customs* dispute* no_clarity  form 
service_delivered profitable man1 man2 man3 man4 management_quality expand ln_sales ln_expenses a11_1 a11_2 a11_3 a14 a16 sales_* oecd_enforce oecd capital labor profit_margin ln_profitmargin;

/***********************************************************************************/



save "data/Working_PCI2017.dta", replace;


/********************************************************/




