/*
September 20, 2020
Created by Edmund Malesky for replication of "Leakag in International Regulatory Regimes:
Did the OECD Anti-Bribery Convention Increase Bribery?" with Terry Chapman, Nathan Jensen, and Scott Wolford.
Use STATA Version 16   

Set Central Directory "C:\Users\ejm5\Dropbox\bribery\qjps R&R"

To run, create 4 sub-files under central directory: 
1. data: stores data files
2. do: stores .do files
3. graphs: captures graphs created by analysis
4. tables: captures tables created by analysis

/*Packages*/
net install outreg2.pkg

Raw Datasets: 
1. Raw_PCI2017.dta: Raw, Anonomyzed PCI_FDI 2017 Datasets
2. oecd_enforcement2.dta; transparnency international coding of OECD-ACB enforcement
3. FDI_by_counterparts.dta: Vietnam General Statistical Office list of FDI data into Vietnam by country
4. cpi.dta: price data to address inflation in country-level FDI dataset
5. oecd_7years_working.dta: Replication data from Malesky and Jensen (2018). Downloaded from Dataverse (https://dataverse.harvard.edu/dataset.xhtml?persistentId=doi:10.7910/DVN/CIDM96).
6. reg_bribe2018.dta: Raw registration bribe data from 2017 PCI-FDI
7. reg_bribe2018.dta: Raw registration bribe data from 2018 PCI-FDI
8. reg_bribe2019.dta: Raw registration bribe data from 2019 PCI-FDI
9. legislation.dta:  Ratification documents from OECD-ABC

Created Datasets:
1. Working_PCI2017.dta: Working data after set-up and cleaning file
2. oecd_country_level.dta: Country-level working data for downstream analysis
3. country_wide.dta: re-orders data for Tables 5 and 6 in SI
4. MaleskyJensen2018: Final Panal Dataset of PCI-FDI covering 2010-2017.
5. reg_bribe20172019: Final Panal Dataset of PCI-FDI covering 2018-2019.


		  
Do Files (Described Below): 
1. 20200920_LeakageReadMe.do;
2. 20200920_LeakageSetup.do; 
3. 20200920_LeakageCountryLevelAnalysis.do; 
4. 20200920_Leakage_FirmLevelAnalysis.do; 
5. 20200920_Leakage_RegistrationBribery.do.


*/

/*1. 20200920_LeakageReadMe.do
Master file that runs all other analysis*/

/*2. 20200920_LeakageSetup.do
Use Raw_PCI2017.dta & oecd_enforcement2.dta
Creates  Working_PCI2017.dta

Begins with Raw survey data; cleaning file that creates industry codes and key variables for firm-level analysis*/
do "C:\Users\ejm5\Dropbox\bribery\qjps R&R\do\20200920_LeakageSetup.do"

/*3. 20200920_LeakageCountryLevelAnalysis.do 
Use FDI_by_counterparts.dta, oecd_enforcement2.dta, cpi.dta
Creates  oecd_country_level.dta & country_wide.dta

.do file begins with set-up of country-level data, then performs country-level analysis, then drops Chinese and Taiwanese firms, 
and finally aggregates to enforcement level analysis for regression table and graphs

Creates:
Table 2: Enforcement Regime Level Difference-in-Difference (Lines 79-148)
SI5 Table 4: Enforcement Regime Level Difference-in-Difference (Lines 90-155)
SI2 Table 3: Summary Statistics and Bivariate Correlations (Country-level Data) (Lines 117-120)
Figure 4: Percentage of Total FDI Projects by Home Country Enforcement, 2005-2015 (Lines 164-171)
Figure 5: Percentage of Dollars of Investment by Home Country Enforcement, 2005-2015 (Lines 174-181)
SI3 Figure 1: Number of FDI Projects by Home Country Enforcement, 2005-2015 (Lines 184-191)
SI4 Figure 2: Investment Size by Home Country Enforcement, 2005-2015 (Lines 194-201)
Final command creates aggregate country level dataset, which is used in SI 6 & 7 below (Lines 205-211)*/
do "C:\Users\ejm5\Dropbox\bribery\qjps R&R\do\20200920_LeakageCountryLevelAnalysis.do"

/*4. 20200920_Leakage_FirmLevelAnalysis.do 
Use Working_PCI2017.dta, country_wide.dta, legislation.dta

Creates:
Table 1: Relationship between Productivity and Bribery (Lines 6-17)
Figure 3: Relationship between Proxies for Productivity (Lines 18-25)
SI8 Table 7: Correlation between Sales and Profit Margin provides regression support for Table 3 (Lines 27-37)
SI10 Table 9: Instrumental Variables Regression using Management Quality provides two-stage test of Table 1 (Lines 40-50)
Figure 6: Subcontracting with Consultants (Lines 53-59)
Table 3: Sub-Contracting by ABC Enforcement Regime (Lines 62-72)
SI1 Table 1: Descriptive Statistics (Firm Data) (Lines 74-88)
SI1 Table 2: Bivariate Correlations (Firm Data) (Line 94)
SI6 Table 5: Description of Countries Used in Analysis (Line 98-111)
SI7 Table 6: New Investment and Project Shares by Country over Time (Line 98-111)*/
do "C:\Users\ejm5\Dropbox\bribery\qjps R&R\do\20201201_Leakage_FirmLevelAnalysis.do"


/*5. 20200920_LeakageRegistrationBribery.do
Use oecd_7years_working.dta, reg_bribe2018.dta, reg_bribe2018.dta, reg_bribe2019.dta
Creates MaleskyJensen2018 &  Extends Malesky Jensen IO Timeseries Data on Registration Bribery to test List Estimator Questions

Set-Up in Lines 5-45
Creates: 
Figure 2: Average Bribe Frequency over Time by List Experiment or Direct Question (Lines 45-187)
SI Table 8: Differential Relationship between Productivity and Bribery (using List Estimator) (Lines 160-208)*/
do "C:\Users\ejm5\Dropbox\bribery\qjps R&R\do\20200920_Leakage_RegistrationBribery.do"
