



/******************************************************************************************************************************************************/
/*Set-Up Time Series Data by Adding to Malesky and Jensen Replication Data*/
#delimit;
use "data/oecd_7years_working.dta", clear;
keep id form pci_id treatment companycountry managercountry c6 year a1  a10_1 a14 sector_plus companycountry managercountry oecd enforce_scale*;
generate oecd_enforce=0 if oecd==0;
replace oecd_enforce=1 if enforce_scale_entry==1;
replace oecd_enforce=2 if enforce_scale_entry>1;
label variable oecd_enforce "Enforcement (Transparency International)";
label values oecd_enforce enforce;
label define enforce 0 "Non-Signatory" 1 "None" 2 "Some" ;
save "data/MaleskyJensen2018", replace;

#delimit;
use  "data/reg_bribe2017.dta", clear;
append using "data/reg_bribe2018.dta";
append using "data/reg_bribe2019.dta";

generate country=companycountry;
replace country=managercountry if companycountry=="";
replace country=managercountry if companycountry=="Vietnam";
replace country= managercountry if companycountry==""|companycountry=="Vietnam";
replace country="Netherlands" if country=="Netherland";
replace country="United Kingdom" if country=="British Virgin Islands";
replace country="China" if country=="Hong Kong";
replace country="Korea" if country=="Republic of Korea";
replace country="Korea" if country=="South Korea";
replace country="United States" if country=="United States of America";
replace country="France" if country=="pháp";
merge m:1 country using "data/oecd_enforcement2.dta";
generate oecd=1 if oecd_enforce==1|oecd_enforce==2;
replace oecd=0 if oecd_enforce==0;
label variable oecd_enforce "Enforcement (Transparency International)";
label values oecd_enforce enforce;
label define enforce 0 "Non-Signatory" 1 "Non-Enforcer" 2 "Enforcer" ;
save "data/reg_bribe20172019", replace;

use "data/MaleskyJensen2018", clear;
append using  "data/reg_bribe20172019";

/******************************************************************************************************************************************************************/
/*Figure 2*/

#delimit cr
preserve
reg c6 treatment if year==2010
generate bribe=_b[treatment] if year==2010
generate se=_se[treatment] if year==2010

reg c6 treatment if year==2011
replace bribe=_b[treatment] if year==2011
replace se=_se[treatment] if year==2011

reg c6 treatment if year==2012
replace bribe=_b[treatment] if year==2012
replace se=_se[treatment] if year==2012

reg c6 treatment if year==2013
replace bribe=_b[treatment] if year==2013
replace se=_se[treatment] if year==2013

reg c6 treatment if year==2014
replace bribe=_b[treatment] if year==2014
replace se=_se[treatment] if year==2014

reg c6 treatment if year==2015
replace bribe=_b[treatment] if year==2015
replace se=_se[treatment] if year==2015

reg c6 treatment if year==2016
replace bribe=_b[treatment] if year==2016
replace se=_se[treatment] if year==2016

reg c4_2017 if year==2017
replace bribe=_b[_cons] if year==2017
replace se=_se[_cons] if year==2017

reg c4_2017 if year==2018
replace bribe=_b[_cons] if year==2018
replace se=_se[_cons] if year==2018

reg c4_2017 if year==2019
replace bribe=_b[_cons] if year==2019
replace se=_se[_cons] if year==2019

collapse bribe se, by(year oecd_enforce)
generate high=bribe+1.96*se
generate low=bribe-1.96*se


#delimit;
twoway (rcap high low year) (scatter bribe year if year<=2016, mcolor(gs4)) (scatter bribe year if year>=2017, mcolor(gs8)), scheme(s1mono) xlab(2010(1)2019, labsize(vsmall)) ylab(0(.05).8, labsize(small)) xtitle("") ytitle("Estimated Bribe Frequency during Licensing", size(medium) margin(medsmall)) legend(size(medsmall) rows(3) label(1 "95% CI") label(2 "List") label(3 "Direct")  ring(0) position(11)) xline(2016.5, lcolor(black) lwidth(thick) lpattern(dash)) title("All Firms", size(medlarge) margin(medmall));
graph save "graphs/Figure2a.gph", replace;
restore;

#delimit cr
preserve
keep if oecd_enforce==2
#delimit cr
reg c6 treatment if year==2010
generate bribe=_b[treatment] if year==2010
generate se=_se[treatment] if year==2010

reg c6 treatment if year==2011
replace bribe=_b[treatment] if year==2011
replace se=_se[treatment] if year==2011

reg c6 treatment if year==2012
replace bribe=_b[treatment] if year==2012
replace se=_se[treatment] if year==2012

reg c6 treatment if year==2013
replace bribe=_b[treatment] if year==2013
replace se=_se[treatment] if year==2013

reg c6 treatment if year==2014
replace bribe=_b[treatment] if year==2014
replace se=_se[treatment] if year==2014

reg c6 treatment if year==2015
replace bribe=_b[treatment] if year==2015
replace se=_se[treatment] if year==2015

reg c6 treatment if year==2016
replace bribe=_b[treatment] if year==2016
replace se=_se[treatment] if year==2016

reg c4_2017 if year==2017
replace bribe=_b[_cons] if year==2017
replace se=_se[_cons] if year==2017

reg c4_2017 if year==2018
replace bribe=_b[_cons] if year==2018
replace se=_se[_cons] if year==2018

reg c4_2017 if year==2019
replace bribe=_b[_cons] if year==2019
replace se=_se[_cons] if year==2019

collapse bribe se, by(year oecd_enforce)
generate high=bribe+1.96*se
generate low=bribe-1.96*se


#delimit;
twoway (rcap high low year) (scatter bribe year if year<=2016, mcolor(gs4)) (scatter bribe year if year>=2017, mcolor(gs8)), scheme(s1mono) xlab(2010(1)2019, labsize(vsmall)) ylab(0(.05).8, labsize(small)) xtitle("") ytitle("Estimated Bribe Frequency during Licensing", size(medium) margin(medsmall))  xline(2016.5, lcolor(black) lwidth(thick) lpattern(dash)) title("Firms from OECD Enforcers", size(medlarge) margin(medmall)) legend(off);
graph save "graphs/Figure2b.gph", replace;
restore;

 
graph combine "graphs/Figure2a.gph" "graphs/Figure2b.gph", xcommon ycommon imargin(tiny) scheme(s1color);
graph save "graphs/Figure2.gph", replace;
graph export "graphs/Figure2.pdf", as(pdf) replace;
/******************************************************************************************************************************************************************/

/*SI9 Table 8*/
#delimit;
use "data/oecd_7years_working.dta", clear;
keep if year>2011;
replace oecd_enforce=0 if oecd==0;
replace oecd_enforce=1 if enforce_scale_entry==1;
replace oecd_enforce=2 if oecd_enforce>1;

replace ln_sales=ln(a14+1);
rename a10_1 labor_origin;
rename a5_1 capital_origin;
encode sector_plus, gen(sector_id);

label variable oecd_enforce "Enforcement (Transparency International)";
label values oecd_enforce enforce;
label define enforce 0 "Non-Signatory" 1 "Non-Enforcer" 2 "Enforcer" ;

set more off;
set seed 20200706;
reg c6 i.oecd_enforce c.ln_sales  if treatment==0,  cluster(country_id);
predict ns_items;
generate reg_bribe=c6-ns_items;
reg reg_bribe i.oecd_enforce c.ln_sales  if treatment==1,   vce(bootstrap, reps(1000)) cluster(country_id);
outreg2 using "tables/SI_Table8",  bdec(3) tdec(3) e(N N_clust  rmse ll ) noaster ctitle("Bivariate")  keep(i.oecd_enforce c.ln_sales) addtext("ISIC Two Digit Fixed Effects", No, "Entry Year Fixed Effects", No) replace;
drop ns_items reg_bribe;

set more off;
areg c6 i.oecd_enforce c.ln_sales   if treatment==0, absorb(sector_id) cluster(country_id);
predict ns_items;
generate reg_bribe=c6-ns_items;
areg reg_bribe i.oecd_enforce c.ln_sales  if treatment==1,   vce(bootstrap, reps(1000)) absorb(sector_id) cluster(country_id);
outreg2 using "tables/SI_Table8",  bdec(3) tdec(3) e(N N_clust  rmse ll ) noaster ctitle("Sector FE")  keep(i.oecd_enforce c.ln_sales) addtext("ISIC Two Digit Fixed Effects", Yes, "Entry Year Fixed Effects", No) excel;
drop ns_items reg_bribe;

#delimit;
set more off;
areg c6 i.oecd_enforce c.ln_sales labor_origin capital_origin i.a1  if treatment==0, absorb(sector_id) cluster(country_id);
predict ns_items;
generate reg_bribe=c6-ns_items;
areg reg_bribe i.oecd_enforce c.ln_sales labor_origin capital_origin i.a1 if treatment==1,   vce(bootstrap, reps(1000)) absorb(sector_id) cluster(country_id);
outreg2 using "tables/SI_Table8",  bdec(3) tdec(3) e(N N_clust  rmse ll ) noaster ctitle("Controls")  keep(i.oecd_enforce c.ln_sales labor_origin capital_origin) addtext("ISIC Two Digit Fixed Effects", Yes, "Entry Year Fixed Effects", Yes);
drop ns_items reg_bribe;

set more off;
areg c6 i.oecd_enforce c.ln_sales labor_origin capital_origin  i.a1  if treatment==0 & companycountry !="China" & companycountry != "Taiwan", absorb(sector_id) cluster(country_id);
predict ns_items;
generate reg_bribe=c6-ns_items;
areg reg_bribe i.oecd_enforce c.ln_sales labor_origin capital_origin i.a1 if treatment==1 & companycountry !="China" & companycountry != "Taiwan",   vce(bootstrap, reps(1000)) absorb(sector_id) cluster(country_id);
outreg2 using "tables/SI_Table8",  bdec(3) tdec(3) e(N N_clust  rmse ll ) noaster ctitle("Drop China/Taiwan")  keep(i.oecd_enforce c.ln_sales labor_origin capital_origin) addtext("ISIC Two Digit Fixed Effects", Yes, "Entry Year Fixed Effects", Yes) excel;
















